class Cas:
    INVENTORY="""第一章　总则
第一条　为了规范存货的确认、计量和相关信息的披露，根据《企业会计准则——基本准则》，制定本准则。
第二条　下列各项适用其他相关会计准则：
（一）消耗性生物资产，适用《企业会计准则第5号——生物资产》。
（二）通过建造合同归集的存货成本，适用《企业会计准则第15号——建造合同》。
第二章　确认
第三条　存货，是指企业在日常活动中持有以备出售的产成品或商品、处在生产过程中的在产品、在生产过程或提供劳务过程中耗用的材料和物料等。
第四条　存货同时满足下列条件的，才能予以确认：
（一）与该存货有关的经济利益很可能流入企业；
（二）该存货的成本能够可靠地计量。
第三章　计量
第五条　存货应当按照成本进行初始计量。存货成本包括采购成本、加工成本和其他成本。
第六条　存货的采购成本，包括购买价款、相关税费、运输费、装卸费、保险费以及其他可归属于存货采购成本的费用。
第七条　存货的加工成本，包括直接人工以及按照一定方法分配的制造费用。
制造费用，是指企业为生产产品和提供劳务而发生的各项间接费用。企业应当根据制造费用的性质，合理地选择制造费用分配方法。
在同一生产过程中，同时生产两种或两种以上的产品，并且每种产品的加工成本不能直接区分的，其加工成本应当按照合理的方法在各种产品之间进行分配。
第八条　存货的其他成本，是指除采购成本、加工成本以外的，使存货达到目前场所和状态所发生的其他支出。
第九条　下列费用应当在发生时确认为当期损益，不计入存货成本：
（一）非正常消耗的直接材料、直接人工和制造费用。
（二）仓储费用（不包括在生产过程中为达到下一个生产阶段所必需的费用）。
（三）不能归属于使存货达到目前场所和状态的其他支出。
第十条　应计入存货成本的借款费用，按照《企业会计准则第17号——借款费用》处理。
第十一条　投资者投入存货的成本，应当按照投资合同或协议约定的价值确定，但合同或协议约定价值不公允的除外。
第十二条　收获时农产品的成本、非货币性资产交换、债务重组和企业合并取得的存货的成本，应当分别按照《企业会计准则第5号——生物资产》、《企业会计准则第7号——非货币性资产交换》、《企业会计准则第12号——债务重组》和《企业会计准则第20号——企业合并》确定。
第十三条　企业提供劳务的，所发生的从事劳务提供人员的直接人工和其他直接费用以及可归属的间接费用，计入存货成本。
第十四条　企业应当采用先进先出法、加权平均法或者个别计价法确定发出存货的实际成本。
对于性质和用途相似的存货，应当采用相同的成本计算方法确定发出存货的成本。
对于不能替代使用的存货、为特定项目专门购入或制造的存货以及提供的劳务，通常采用个别计价法确定发出存货的成本。
对于已售存货，应当将其成本结转为当期损益，相应的存货跌价准备也应当予以结转。
第十五条　资产负债表日，存货应当按照成本与可变现净值孰低计量。
存货成本高于其可变现净值的，应当计提存货跌价准备，计入当期损益。
可变现净值，是指在日常活动中，存货的估计售价减去至完工时估计将要发生的成本、估计的销售费用以及相关税费后的金额。
第十六条　企业确定存货的可变现净值，应当以取得的确凿证据为基础，并且考虑持有存货的目的、资产负债表日后事项的影响等因素。
为生产而持有的材料等，用其生产的产成品的可变现净值高于成本的，该材料仍然应当按照成本计量；材料价格的下降表明产成品的可变现净值低于成本的，该材料应当按照可变现净值计量。
第十七条　为执行销售合同或者劳务合同而持有的存货，其可变现净值应当以合同价格为基础计算。
企业持有存货的数量多于销售合同订购数量的，超出部分的存货的可变现净值应当以一般销售价格为基础计算。
第十八条　企业通常应当按照单个存货项目计提存货跌价准备。
对于数量繁多、单价较低的存货，可以按照存货类别计提存货跌价准备。
与在同一地区生产和销售的产品系列相关、具有相同或类似最终用途或目的，且难以与其他项目分开计量的存货，可以合并计提存货跌价准备。
第十九条　资产负债表日，企业应当确定存货的可变现净值。以前减记存货价值的影响因素已经消失的，减记的金额应当予以恢复，并在原已计提的存货跌价准备金额内转回，转回的金额计入当期损益。
第二十条　企业应当采用一次转销法或者五五摊销法对低值易耗品和包装物进行摊销，计入相关资产的成本或者当期损益。
第二十一条　企业发生的存货毁损，应当将处置收入扣除账面价值和相关税费后的金额计入当期损益。存货的账面价值是存货成本扣减累计跌价准备后的金额。
存货盘亏造成的损失，应当计入当期损益。
第四章　披露
第二十二条　企业应当在附注中披露与存货有关的下列信息：
（一）各类存货的期初和期末账面价值。
（二）确定发出存货成本所采用的方法。
（三）存货可变现净值的确定依据，存货跌价准备的计提方法，当期计提的存货跌价准备的金额，当期转回的存货跌价准备的金额，以及计提和转回的有关情况。
（四）用于担保的存货账面价值。
        """